==> mariadb-5.5.34.tar.gz: mariadb-5.5.34/storage/ndb/src/common/logger/loggertest/LoggerUnitTest.hpp <==
/* Copyright (C) 2003 MySQL AB

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA */

#ifndef LOGGERUNITTEST_H
#define LOGGERUNITTEST_H

#include "Logger.hpp"

/**
  * Unit test of Logger.
  *
  * @version #@ $Id: LoggerUnitTest.hpp,v 1.1 2002/03/13 17:55:31 eyualex Exp $
  */
class LoggerUnitTest
{
public:
  
  static bool testAll(const char* msg);
  static bool testOff(const char* msg);	
  static bool testAlert(const char* msg);
  static bool testCritical(const char* msg);
  static bool testError(const char* msg);
  static bool testWarning(const char* msg);
  static bool testInfo(const char* msg);
  static bool testDebug(const char* msg);
  static bool testInfoCritical(const char* msg);

  static bool logTo(Logger::LoggerLevel level, const char* msg);
  static bool logTo(Logger::LoggerLevel from, Logger::LoggerLevel to, const char* msg);
  
  void error(const char* msg);
  
  LoggerUnitTest();
  ~LoggerUnitTest();
};
#endif

==> mariadb-5.5.67.tar.gz: mariadb-5.5.67/storage/ndb/src/common/logger/loggertest/LoggerUnitTest.hpp <==
/* Copyright (c) 2003, 2005 MySQL AB
   Use is subject to license terms

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1335  USA */

#ifndef LOGGERUNITTEST_H
#define LOGGERUNITTEST_H

#include "Logger.hpp"

/**
  * Unit test of Logger.
  *
  * @version #@ $Id: LoggerUnitTest.hpp,v 1.1 2002/03/13 17:55:31 eyualex Exp $
  */
class LoggerUnitTest
{
public:
  
  static bool testAll(const char* msg);
  static bool testOff(const char* msg);	
  static bool testAlert(const char* msg);
  static bool testCritical(const char* msg);
  static bool testError(const char* msg);
  static bool testWarning(const char* msg);
  static bool testInfo(const char* msg);
  static bool testDebug(const char* msg);
  static bool testInfoCritical(const char* msg);

  static bool logTo(Logger::LoggerLevel level, const char* msg);
  static bool logTo(Logger::LoggerLevel from, Logger::LoggerLevel to, const char* msg);
  
  void error(const char* msg);
  
  LoggerUnitTest();
  ~LoggerUnitTest();
};
#endif
